/* --------------------------------------------------------------------
 * DEFINES for wmmaiload
 * --------------------------------------------------------------------
 */

#ifndef DEFINES_H
#define DEFINES_H

/*
 * AT THIS POINT, COMMENT OUT FEATURES YOU DON'T WANT TO HAVE INCLUDED
 * IN THE PROGRAM.
 */


/* Comment this out if you don't want to have local mbox support */
#define HAVE_MBOX

/* Comment this out if you don't want to have MailDir support */
#define HAVE_MAILDIR

/* Comment this out if you don't want to have POP3/Hotmail support */
#define HAVE_POP3

/* Comment this out if you don't want to have MH support */
#define HAVE_MH

/* Comment this out if you don't want to have IMAP support */
#define HAVE_IMAP


#endif /* DEFINES_H */

